summaryrefslogtreecommitdiff
path: root/src/flake8/statistics.py
diff options
context:
space:
mode:
authorIan Cordasco <graffatcolmingov@gmail.com>2017-06-04 20:11:32 +0000
committerIan Cordasco <graffatcolmingov@gmail.com>2017-06-04 20:11:32 +0000
commit01f8824490a58720045e6acbb027613db05dfc7e (patch)
tree3881cfabb2ec79b9869c1a56ad4c72fc1acf584b /src/flake8/statistics.py
parentfeec0754bd2f9c1f3b64ac309481cdfe40162bb7 (diff)
parentff07ca3ed9a650b7f23866e11860bad9583e8acf (diff)
downloadflake8-01f8824490a58720045e6acbb027613db05dfc7e.tar.gz
Merge branch 'refactor-decision-engine' into 'master'
Refactor decision logic into its own object See merge request !190
Diffstat (limited to 'src/flake8/statistics.py')
-rw-r--r--src/flake8/statistics.py9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/flake8/statistics.py b/src/flake8/statistics.py
index d555df2..d39750a 100644
--- a/src/flake8/statistics.py
+++ b/src/flake8/statistics.py
@@ -23,9 +23,10 @@ class Statistics(object):
"""Add the fact that the error was seen in the file.
:param error:
- The Error instance containing the information about the violation.
+ The Violation instance containing the information about the
+ violation.
:type error:
- flake8.style_guide.Error
+ flake8.style_guide.Violation
"""
key = Key.create_from(error)
if key not in self._store:
@@ -73,7 +74,7 @@ class Key(collections.namedtuple('Key', ['filename', 'code'])):
@classmethod
def create_from(cls, error):
"""Create a Key from :class:`flake8.style_guide.Error`."""
return cls(
filename=error.filename,
code=error.code,
@@ -115,7 +116,7 @@ class Statistic(object):
@classmethod
def create_from(cls, error):
"""Create a Statistic from a :class:`flake8.style_guide.Error`."""
return cls(
error_code=error.code,
filename=error.filename,
@@ -73,7 +74,7 @@ class Key(collections.namedtuple('Key', ['filename', 'code'])):
def create_from(cls, error):
- """Create a Key from :class:`flake8.style_guide.Error`."""
+ """Create a Key from :class:`flake8.style_guide.Violation`."""
return cls(
filename=error.filename,
@@ -115,7 +116,7 @@ class Statistic(object):
def create_from(cls, error):
- """Create a Statistic from a :class:`flake8.style_guide.Error`."""
+ """Create a Statistic from a :class:`flake8.style_guide.Violation`."""
return cls(
error_code=error.code,